#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 resourcet
version:              1.2.4.2
visibility:           public
id:                   resourcet-1.2.4.2-AvaFhfxp8uvAOEEUNRGsFz
key:                  resourcet-1.2.4.2-AvaFhfxp8uvAOEEUNRGsFz
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.

category:             Data, Conduit
abi:                  1d6b86389046a586a46e62202224f148
exposed:              True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource

import-dirs:          /usr/lib/ghc-8.10.5/site-local/resourcet-1.2.4.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/resourcet-1.2.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/resourcet-1.2.4.2
hs-libraries:         HSresourcet-1.2.4.2-AvaFhfxp8uvAOEEUNRGsFz
depends:
    base-4.14.2.0 containers-0.6.4.1 exceptions-0.10.4 mtl-2.2.2
    primitive-0.7.1.0-H44eQ1j8hQJ3Kj2SFx0Ivh transformers-0.5.6.2
    unliftio-core-0.2.0.1-1ibY1oF6Hkc5ZYjZ4yW3Lp

haddock-interfaces:   /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html:         /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

